var mask;
var animationId = 0;
var staticId = 0;

function init(){
    mask = jsMaskSingleton.getCurrentMask();
}

function log(text) {
    android.util.Log.i("Javascript", text);
}

function destroyScene(){
}

function Animation(params) {
    this.width = params.width;
    this.height = params.height;
    this.anchor = params.anchor === undefined ? 0 : params.anchor;
    this.offset = params.offset === undefined ? [0, 0, 0] : params.offset;
    this.rotation = params.rotation === undefined ? [0, 0, 0] : params.rotation;
    this.singleFrameTimeMillis = 1.0 / params.fps;
    this.accumulatedTime = 0;
    this.numFrames = params.frames;
    this.currentFrame = 0;
    this.previousFrame = 0;
    this.images = [];
    this.id = animationId;
    animationId += 1;
    for (i = 1; i <= this.numFrames; i++) {
      this.images[i - 1] = (params.assets + "_" + (i < 10 ? "0" + i : i) + ".png").toString();
    }
};

Animation.prototype.init = function(mask) {
    for (i = 0; i < this.numFrames; ++i) {
        var id = (this.id * 100 + i).toString();
        mask.jsCreatePlane(id, this.images[i], this.width, this.height);
        this.images[i] = id;
    }
    mask.jsAddObjectsToLayer("layer2d", this.images);
}

Animation.prototype.drawFrame = function(mask) {
  // If we have a new frame, remove the last one
  if (this.previousFrame != this.currentFrame) {
    mask.jsTransformObject(this.images[this.previousFrame], 0, 0, 0, 0);
    this.previousFrame = this.currentFrame;
  }

  // Update the current frame to its new location
  var image = this.images[this.currentFrame];
  mask.jsStickObjectToFaceAndTransform3(image, this.anchor, this.offset, this.rotation, [1, 1, 1]);
}

Animation.prototype.update = function(deltaTime) {
  this.accumulatedTime += deltaTime;
  if (this.accumulatedTime > this.singleFrameTimeMillis) {
    this.accumulatedTime -= this.singleFrameTimeMillis;
    this.previousFrame = this.currentFrame;
    this.currentFrame = (this.currentFrame + 1) % this.numFrames;
  }
}

function Static() {
  var i = arguments.length;
  var planes = [];
  while (i--) planes[i] = arguments[i];
  this.planes = planes;
  this.id = staticId;
  staticId += arguments.length;
}

Static.prototype.init = function(mask) {
  for (i = 0; i < this.planes.length; ++i) {
    var plane = this.planes[i];
    var id = (plane.image + (this.id + i)).toString();
    mask.jsCreatePlane(id, plane.image, plane.width, plane.height);
    plane.image = id;
    mask.jsAddObjectsToLayer("layer2d", [ plane.image ]);
  }
}

Static.prototype.drawFrame = function(mask) {
  for (i = 0; i < this.planes.length; ++i) {
    var plane = this.planes[i];
    var offset = plane.offset;
    var rotation = plane.rotation === undefined ? [0, 0, 0] : plane.rotation
    mask.jsStickObjectToFaceAndTransform3(plane.image, plane.anchor, offset, rotation, [1, 1, 1]);
  }
}
